pytest\_run\_subprocess package
=====================================================================


Module contents
---------------

.. automodule:: pytest_run_subprocess
   :members:
   :undoc-members:
   :show-inheritance:
